@@ -11,9 +11,9 @@ use Exporter qw(import);
 use List::Util qw(first max);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-01-21'; # DATE
+our $DATE = '2022-01-23'; # DATE
 our $DIST = 'Perinci-Result-Format-Lite'; # DIST
-our $VERSION = '0.284'; # VERSION
+our $VERSION = '0.285'; # VERSION
 
 our @EXPORT_OK = qw(format);
 
@@ -356,7 +356,7 @@ sub __gen_table {
                 rows => $data,
                 header_row => $header_row,
                 backend => $backend,
-                (title => $resmeta->{title}) x !!defined($resmeta->{title}),
+                (caption => $resmeta->{caption}) x !!defined($resmeta->{caption}),
             );
         } else {
             require Text::Table::Sprintf;
@@ -551,7 +551,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.284 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2022-01-21.
+This document describes version 0.285 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2022-01-23.
 
 =head1 SYNOPSIS
 
